import argparse

from clippy.cookbook import Cookbook
from clippy.remote import RemoteCommandError, RemoteHosts


class PuppetEnroll(Cookbook):
    """Enroll a host in Puppet."""

    def argument_parser(self) -> argparse.ArgumentParser:
        parser = super().argument_parser()
        parser.add_argument("fqdn")
        return parser

    def _run_command_until_successful(self, command: str, remote: RemoteHosts):
        while True:
            try:
                remote.execute(command=command, show_output=True)
                break
            except RemoteCommandError as e:
                self.logger.warning("Failed to run '%s' on %s", command, self.args.fqdn)
                ans = input("> Retry [Y/n]? ")
                if ans.strip().lower() == "n":
                    raise e

    def execute(self):
        puppet_host = self.clippy.puppet_hosts(self.args.fqdn)
        puppet_host.sign_certificates()

        installer_host = self.clippy.remote_instance("installer").query(f"D{{{self.args.fqdn}}}")
        self._run_command_until_successful(command="puppet agent -tv", remote=installer_host)

        host = self.clippy.remote_hosts(f"D{{{self.args.fqdn}}}")
        host.reboot()
