import argparse

from clippy.apt import APT_GET_BASE_COMMAND
from clippy.cookbook import Cookbook


class UpgradeNode(Cookbook):
    """Upgrades a single Kubernetes worker."""

    def argument_parser(self) -> argparse.ArgumentParser:
        parser = super().argument_parser()
        parser.add_argument("--fqdn", "-f", required=True)
        parser.add_argument("--cluster", "-c", required=True)
        return parser

    def execute(self):
        cluster = self.clippy.kubernetes_cluster(self.args.cluster)
        worker = cluster.worker(self.args.fqdn)
        remote = self.clippy.remote_hosts(f"D{{{self.args.fqdn}}}")

        with worker.depooled():
            remote.execute(command="run-puppet-agent --force", show_output=True)
            remote.execute(command=f"{APT_GET_BASE_COMMAND} update", show_output=True)
            remote.execute(command=f"{APT_GET_BASE_COMMAND} install kubeadm", show_output=True)
            remote.execute(command="kubeadm upgrade node", show_output=True)
            remote.execute(command=f"{APT_GET_BASE_COMMAND} dist-upgrade", show_output=True)
            remote.reboot()
